==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Son videoyu postala</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Bir veya daha fazla seçili videoyu postala</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video gibi eklenti bul</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Bir veya daha fazla dosya seçin</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Çerçevesiz</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Çerçeve</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Web kamerası</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Aygıt meşgul</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Web kamera seç</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Bölge</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Büyütme</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Fare imlecini kaydetme</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video yolu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Oynatıcı</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Kayıt başladığında Vokoscreen programını küçült</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Kayıt süresi</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>KB olarak boyut</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Kayıt ekran boyutu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>fps ayarı</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Dizin Aç</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Geri sayım</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Son videoyu oynat</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Video Gönder</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seçin</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Saniye başına fiili kare</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Aygıt %1 meşgul</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>Aktif pencelereler ayarlar için çok yüksek</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Git</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Ana Sayfa</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Eposta listesi</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Destek</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Geliştirici</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Çerçeveler</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Yardım et</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Kayıt programı</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Çeviriler</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Aygıt meşgul</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Son videoyu postala</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Bir veya daha fazla seçili videoyu postala</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video gibi eklenti bul</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Bir veya daha fazla dosya seçin</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Çerçeve</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Aygıt meşgul</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Bölge</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Büyütme</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Fare imlecini kaydetme</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video yolu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Oynatıcı</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Kayıt başladığında Vokoscreen programını küçült</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Kayıt süresi</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>KB olarak boyut</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Kayıt ekran boyutu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>fps ayarı</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Dizin Aç</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Geri sayım</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Son videoyu oynat</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Video Gönder</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seçin</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Saniye başına fiili kare</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Git</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Ana Sayfa</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Eposta listesi</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Destek</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Geliştirici</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Çerçeveler</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Yardım et</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Kayıt programı</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Çeviriler</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Web kamerası</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Web kamera seç</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
